diff --git a/pcl_expect/popen.py b/pcl_expect/popen.py
index 72f9ebf86843e2700ed4cd6a74d4ebd8976551e1..975b2fad08b6f3d6a9f2763f53d74669d68db493 100644
--- a/pcl_expect/popen.py
+++ b/pcl_expect/popen.py
@@ -28,9 +28,10 @@ __all__ = [
     ]
 
 class Popen(pcl_expect.Expectable):
-    def __init__(self, cmd):
-        """Run cmd via os.popen."""
-        self.__cmd = os.popen(cmd, "r")
+    def __init__(self, command):
+        """Run command via os.popen, reading its output.
+        """
+        self.__cmd = os.popen(command, "r")
         pcl_expect.Expectable.__init__(self, self.__cmd.fileno())
 
     def close(self):